<script setup name="LockManage">
	import { ref, onMounted, reactive, computed, watchEffect, nextTick } from "vue";
	import useStation from "@/hooks/useStationList.js";
	const { stationName1, stationName2, stationName3, stationName4,
		stationList1, stationList2, stationList3, stationList4,
	} = useStation();

	import {
		getAllLockInf,
		delLock,
		lockOpen,
    openLockBl,
    closeLockBl
	} from '@/api/lockManager.js';
  import { storeToRefs } from "pinia";

import { useUserStore } from '@/store/user.js';
const userStore = useUserStore();
const { urole, permits } = storeToRefs(userStore);
	import useWebSocket from "@/hooks/useWebsocket.js";
  import isHasPermit from '@/utils/isHasPermit';

	import addEdit from './addEdit.vue';
	import useElement from "@/hooks/useElement.js";

	const { $loading, $message, $confirm, $confirmPwdDo } = useElement();
	const { sendData, message: listMessage } = useWebSocket("lockRt");

	const disabled = ref(false);
	const background = ref(false);
	const addEditVisible = ref(false);
	const isAdd = ref(false);

	const currentAreaId = ref();

	// const themes = ref(const_theme);
	// const theme = store.settings().theme;
	const tableData = ref([]);

	const addEditTitle = ref('');

	const filter = reactive({
		name: "",
		state: undefined,
		type: undefined,
	});

	const page = reactive({
		pageNum: 1,
		pageSize: 20,
		total: 0,
	});

	// 当前编辑的锁对象
	const editLock = ref();

  // 是否有控制权限
let isCanControl = isHasPermit("control_permit", permits.value);

	onMounted(() => {
		// setTimeout(() => {
		// 	console.log('onMounted', stationName1, stationName2, stationName3, stationName4, '=============');

		// }, 2000);
    sendMessage();
	});


	function sendMessage() {
		let params = {
			lockName: filter.name.trim() || undefined,
			lockState: filter.state,
			// lockType: filter.type,
      stationName1: stationName1.value || undefined,
      stationName2: stationName2.value || undefined,
      stationName3: stationName3.value || undefined,
      stationName4: stationName4.value || undefined,
			pageNum: page.pageNum,
			pageSize: page.pageSize,
		};
		sendData(
			JSON.stringify(params)
		);
	}


	watchEffect(() => {
		let _total = 0;
		let _list = [];
		if (listMessage.value) {
			const {
				code,
				data,
				data2
			} = JSON.parse(listMessage.value);

			if (code && data) {
				let { list, total } = data2;
				_list = list.map(v => {
					v.state = { 0: '已闭锁', 1: '已开锁' }[v.lockState];
					v.onlineState = { 0: '离线', 1: '在线' }[v.lockOnline];
					// v.type = { 1: '蓝牙锁', 2: 'ID锁', 3: '实体锁' }[v.lockType];
					v.modelStr = v.model == 1 ? '在线模式' : '离线模式';
					v.blStateStr = v.blState == 0 ? '蓝牙关闭' : '蓝牙开启';
					v.ID = v.lockId % 1000;
					return v;
				});
				_total = total;
			}
		}
		tableData.value = _list;
		page.total = _total;
	});


	function handleSizeChange(val) {
		page.pageSize = val;
		sendMessage();
	}

	function handleCurrentChange(val) {
		page.pageNum = val;
		sendMessage();
	}

	function edit(scope) {
		console.log('scope', scope, '=============');
		let {
			row
		} = scope;
		editLock.value = row;
		addEditTitle.value = '修改锁具';
		isAdd.value = false;
		addEditVisible.value = true;
	}

	function okHandle() {
		addEditVisible.value = false;
		sendMessage();
	}

	function add() {
		isAdd.value = true;
		addEditVisible.value = true;
	}

	function batchAdd() {
		isAdd.value = true;
		addEditVisible.value = true;
	}

	function confirmDel(params) {
		$confirm("删除该锁具", () => {
			del(params.row.lockId);
		});
	}

	function open(scope) {
		console.log('scope', scope, '=============');
		let {
			row
		} = scope;
    $confirmPwdDo(() => {
			let loading = $loading();
			lockOpen(scope.row.lockId).then((res) => {
				let { code, data } = res;
				loading.close();
				if (code && data) {
					$message.success("操作成功");
					sendMessage();
				} else {
					$message.error("操作失败");
				}
			})
				.catch((err) => {
					console.log(err);
					loading.close();
				});

		});

	}

	function del(id) {
		let loading = $loading();
		delLock(id).then((res) => {
			let { code, data } = res;
			loading.close();
			if (code && data) {
				$message.success("操作成功");
				sendMessage();
			} else {
				$message.success("操作失败");
			}
		})
			.catch((err) => {
				console.log(err);
				loading.close();
			});

	}

  function openBl(scope) {
    $confirmPwdDo(() => {
      let loading = $loading();
      openLockBl(
        scope.row.lockId
      ).then((res) => {
        let { code, data } = res;
        loading.close();
        if (code && data) {
          console.log(data);
          $message.success("操作成功");
          sendMessage();
        } else {
          $message.error("操作失败");
        }
      })
        .catch((err) => {
          loading.close();
          console.log(err);
        });
    });
}

function closeBl(scope) {
  $confirmPwdDo(() => {
    let loading = $loading();
    closeLockBl(
      scope.row.lockId
    ).then((res) => {
      let { code, data } = res;
      loading.close();
      if (code && data) {
        console.log(data);
        $message.success("操作成功");
        sendMessage();
      } else {
        $message.error("操作失败");
      }
    })
      .catch((err) => {
        loading.close();
        console.log(err);
      });
  });
}
</script>

<template>
  <div class="page-wrapper">
    <div class="page-header"></div>
    <div class="page-content">
      <yc-card is-full>
        <div class="page-content-wrapper">
          <div class="page-content-tools">
            <el-button type="primary" size="small" @click="add"><svg-icon icon-class="add"></svg-icon>添加</el-button>
            <!-- <el-button type="primary" size="small" :icon="Plus" @click="batchAdd">批量添加</el-button> -->
            |
            <div class="tools-filter">
              <div class="tools-filter-item">
                <div class="filter-label">省：</div>
                <div class="filter-content">
                  <el-select v-model="stationName1" clearable  placeholder="请选择" @change="() => nextTick(() => sendMessage())" size="small"
                    style="width: 180px">
                    <el-option v-for="(item, idx) in stationList1" :key="'province_' + idx" :label="item" :value="item" />
                  </el-select>
                </div>
              </div>
              <div class="tools-filter-item">
                <div class="filter-label">市：</div>
                <div class="filter-content">
                  <el-select v-model="stationName2" clearable  placeholder="请选择" @change="() => nextTick(() => sendMessage())" size="small"
                    style="width: 180px">
                    <el-option v-for="(item, idx) in stationList2" :key="'city_' + idx" :label="item" :value="item" />
                  </el-select>
                </div>
              </div>
              <div class="tools-filter-item">
                <div class="filter-label">区县：</div>
                <div class="filter-content">
                  <el-select v-model="stationName3" clearable placeholder="请选择" @change="() => nextTick(() => sendMessage())" size="small"
                    style="width: 180px">
                    <el-option v-for="(item, idx) in stationList3" :key="'list2_' + idx" :label="item" :value="item" />
                  </el-select>
                </div>
              </div>
              <div class="tools-filter-item">
                <div class="filter-label">机房：</div>
                <div class="filter-content">
                  <el-select v-model="stationName4" clearable placeholder="请选择" @change="() => nextTick(() => sendMessage())" size="small"
                    style="width: 180px">
                    <el-option v-for="(item, idx) in stationList4" :key="'list3_' + idx" :label="item" :value="item" />
                  </el-select>
                </div>
              </div>

              <div class="tools-filter-item">
                <div class="filter-label">锁具名称：</div>
                <div class="filter-content">
                  <el-input @input="sendMessage" placeholder="请输入锁具名称..." v-model="filter.name" size="small"></el-input>
                </div>
              </div>
              <div class="tools-filter-item">
                <div class="filter-label">锁具状态：</div>
                <div class="filter-content">
                  <el-select v-model="filter.state" placeholder="请选择" @change="sendMessage" size="small"
                    style="width: 180px">
                    <el-option label="--请选择--" value="" />
                    <el-option label="闭锁" :value="0" />
                    <el-option label="开锁" :value="1" />
                  </el-select>
                </div>
              </div>
            </div>
            <el-button type="primary" size="small" @click="sendMessage"><svg-icon icon-class="search"></svg-icon>查询</el-button>
          </div>
          <div class="page-content-table">
            <div class="pos-rel">
              <div class="pos-abs">
                <el-table stripe :data="tableData" border style="width: 100%; height: 100%">
                  <el-table-column type="index" fixed="left" width="50" />
                  <el-table-column prop="type" label="类型" width="180" />
                  <el-table-column prop="lockName" label="锁具名称" width="180" />
                  <el-table-column prop="lockId" label="锁ID" width="120" />
                  <el-table-column prop="ID" label="锁具地址" width="120" />
                  <el-table-column prop="stationName" label="机房" min-width="180" />
                  <el-table-column prop="lockIp" label="机房Ip" min-width="180" />
                  <el-table-column prop="modelStr" label="控制模式" width="180" />
                  <el-table-column prop="onlineState" label="在线状态" width="180" />
                  <!-- <el-table-column prop="state" label="安装状态" width="180" /> -->
                  <el-table-column prop="blStateStr" label="蓝牙状态" width="180" />
                  <!-- <el-table-column prop="lockImg" label="锁具图片" width="180" /> -->
                  <!-- <el-table-column prop="address" label="地址" /> -->
                  <el-table-column align="center" fixed="right" label="操作" width="300">
                    <template #default="scope">
                      <el-button type="danger" size="small"
                        v-if="isCanControl && scope.row.lockOnline == 1 && scope.row.lockState == 0"
                        @click="open(scope)">远程开锁</el-button>
                      <el-button type="primary" v-if="isCanControl && scope.row.blState == 0" size="small"
                        @click="openBl(scope)">开启蓝牙</el-button>
                      <el-button type="primary" v-if="isCanControl && scope.row.blState == 1" size="small" @click="closeBl(scope)">关闭蓝牙</el-button>
                      <el-button type="primary" size="small" @click="edit(scope)">编辑</el-button>
                      <el-button type="danger" size="small" @click="confirmDel(scope)">删除</el-button>
                    </template>
                  </el-table-column>
                </el-table>
              </div>
            </div>
          </div>
          <div class="page-content-page">
            <div class="page-tool"></div>
            <div class="el-page-container">
              <el-pagination v-model:current-page="page.pageNum" v-model:page-size="page.pageSize"
                :page-sizes="[20, 40, 60, 80, 100, 200, 300, 400]" size="small" :disabled="disabled"
                :background="background" layout="total, sizes, prev, pager, next, jumper" :total="page.total"
                @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </div>
            <div class="page-tool"></div>
          </div>
        </div>
      </yc-card>
    </div>
    <div class="page-footer"></div>
    <!-- 编辑 新建 -->
    <el-dialog v-model="addEditVisible" :title="addEditTitle" width="640" align-center :close-on-click-modal="false">
      <add-edit v-if="addEditVisible" :info="editLock" :isAdd="isAdd" @close="addEditVisible = false"
        @ok="okHandle"></add-edit>
    </el-dialog>
  </div>
</template>

<style scoped lang="scss">
.page-wrapper {
  display: flex;
  flex-direction: row;
  padding: 8px;
  height: 100%;

  .page-content {
    flex: 1;
  }
}

.page-content-wrapper {
  display: flex;
  flex-direction: column;
  height: 100%;

  .page-content-tools {
    padding-bottom: 8px;
  }

  .page-content-table {
    border-top: 1px solid var(--border-light-color);
    box-sizing: border-box;
    flex: 1;
    margin-left: -8px;
    margin-right: -8px;
  }

  .page-content-page {
    padding: 8px 8px 0 8px;
    text-align: center;

    .el-page-container {
      display: inline-block;
      padding: 0 16px;
    }

    .page-tool {
      display: inline-block;
    }
  }
}

.hdw-card-container {
  width: 240px;
  padding-right: 8px;
  height: 100%;
}

.pos-rel {
  position: relative;
  width: 100%;
  height: 100%;

  .pos-abs {
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    width: 100%;
    height: 100%;
  }
}

.tools-filter {
  display: inline-block;
  font-size: 14px;

  .tools-filter-item {
    display: inline-block;
    margin-right: 8px;

    .filter-label {
      display: inline-block;
    }

    .filter-content {
      display: inline-block;
    }
  }
}
</style>
